package info.aspirecn.cloud.yysj.cloudyysjlogin.utils;

import com.auth0.jwt.JWT;
import com.auth0.jwt.JWTCreator;
import com.auth0.jwt.algorithms.Algorithm;
import com.auth0.jwt.interfaces.Claim;
import com.auth0.jwt.interfaces.DecodedJWT;
import com.auth0.jwt.interfaces.JWTVerifier;
import info.aspirecn.cloud.yysj.cloudyysjlogin.exceptions.SystemBusyException;
import org.omg.CORBA.SystemException;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;

public class JwtUtils {

    private JwtUtils() {
    }

    /**
     * 签名的私钥
     */
    private static final String SECRET = "9a96349e2345385785e804e0f4254dee";
    /**
     * 签发人
     */
    private static final String ISSUER = "SYS_USER";

    /**
     * 生成token
     *
     * @param claims 加密内容
     * @param time   过期时间，单位(s)
     * @return Token字符串
     */
    public static String createToken(Map<String, String> claims, long time) {
        try {
            // 设置过期时间
            Date expireDate = new Date();
            expireDate.setTime(expireDate.getTime() + time * 1000);
            //使用HMAC256进行加密
            Algorithm algorithm = Algorithm.HMAC256(SECRET);
            //创建jwt
            JWTCreator.Builder builder = JWT.create()
                    .withIssuer(ISSUER).
                            withExpiresAt(expireDate);
            //传入参数
            claims.forEach(builder::withClaim);
            //签名加密
            return builder.sign(algorithm);
        } catch (IllegalArgumentException e) {
            throw new SystemBusyException("创建token异常");
        }
    }

    /**
     * 解密jwt
     *
     * @param token 加密串
     * @return jwt 负载信息
     */
    public static Map<String, String> verifyToken(String token) {
        Algorithm algorithm = null;
        //使用HMAC256进行加密
        algorithm = Algorithm.HMAC256(SECRET);
        //解密
        JWTVerifier verifier = JWT.require(algorithm).withIssuer(ISSUER).build();
        DecodedJWT jwt = verifier.verify(token);
        Map<String, Claim> map = jwt.getClaims();
        Map<String, String> resultMap = new HashMap<>();
        map.forEach((k, v) -> resultMap.put(k, v.asString()));
        return resultMap;
    }

}